# Story 1.1: Basic CLI Command and Project Name Input

**Status:** Draft

## Goal & Context

**User Story:** As a Python developer, I want to run `pyhatchery new <project_name>` so that I can initiate the project generation process and specify the name for my new project.

**Context:** This is the foundational story for PyHatchery. It establishes the primary command-line interface for initiating project generation. All subsequent actions in Epic 1 and other epics depend on successfully capturing the project name here.

## Detailed Requirements

- Implement a main CLI entry point using `argparse` or a similar library.
- The `new` subcommand should accept a mandatory `project_name` argument.
- Perform basic validation on the `project_name` (e.g., ensure it's a valid potential directory name, not empty). Complex validation like PEP 8 and PyPI checks will be handled in Story 1.1A.
- Store the provided project name for later use in generation and further validation.

## Acceptance Criteria (ACs)

- AC1: Running `pyhatchery new my_new_project` executes the command successfully.
- AC2: Running `pyhatchery new` without a project name displays a helpful error message and usage instructions.
- AC3: Invalid project names based on basic syntax (e.g., empty string) result in a clear error message.
- AC4: The provided `project_name` is correctly captured for subsequent processing.

## Technical Implementation Context

**Guidance:** Use the following details for implementation. Refer to the linked `docs/` files for broader context if needed.

- **Relevant Files:**

- **Key Technologies:**

- **API Interactions / SDK Usage:**

- **Data Structures:**

- **Environment Variables:**

- **Coding Standards Notes:**

## Tasks / Subtasks

- [x] Create `src/pyhatchery/__init__.py`.
- [ ] Create `src/pyhatchery/cli.py`.
- [ ] In `cli.py`, implement a function (e.g., `parse_args` or integrated into `main`) using `argparse` to define the `new` subcommand and its `project_name` argument.
- [ ] Add basic validation for `project_name` (not empty, potentially basic character checks for directory name validity).
- [ ] Implement logic to display a help message if `project_name` is missing (AC2).
- [ ] Implement logic to display an error if `project_name` is invalid by basic syntax (AC3).
- [ ] Ensure the `project_name` is captured if valid (AC4).
- [ ] Create `src/pyhatchery/__main__.py` that calls the main function from `cli.py`.
- [ ] Configure `pyproject.toml` to expose `pyhatchery` as a command, pointing to `cli.py:main` or `__main__.py`. Refer to Hatch documentation for setting up scripts/entry points. Example for `[project.scripts]`: `pyhatchery = "pyhatchery.cli:main"`

## Testing Requirements

**Guidance:** Verify implementation against the ACs using the following tests.

- **Unit Tests:**
  - Location: `tests/unit/test_cli.py`
- **Integration Tests:** (Considered E2E/Acceptance for CLI as per `testing-strategy.md`)
  - Location: `tests/integration/test_project_generation.py` (or a dedicated `test_cli_invocation.py`)
- _(Hint: See `docs/testing-strategy.md` for the overall approach)
