# PyHatchery API Reference

This document details the external APIs consumed by PyHatchery. PyHatchery itself does not expose any APIs for external consumption beyond its command-line interface.

## 1. External APIs Consumed

### PyPI API (pypi.org)

* **Purpose:** PyHatchery uses the PyPI JSON API to check if a potential package name (derived from the user's project name) is already registered on the Python Package Index. This check is used to provide a non-blocking warning to the user if the name might be taken.
* **Base URL(s):**
  * Production: `https://pypi.org/`
* **Authentication:** None required for the specific read-only endpoint used for checking package name availability.
* **Key Endpoints Used:**
  * **`GET /pypi/{package_name}/json`**
    * **Description:** Retrieves public metadata for a given package in JSON format. PyHatchery uses this endpoint to determine if a package name exists. If a `200 OK` response is received, it implies the package name is taken. A `404 Not Found` response implies the package name is likely available.
    * **Request Parameters:**
      * `package_name` (Path Parameter, string): The name of the package to check (e.g., `my-cool-project`). This corresponds to the PyPI-friendly slug generated by PyHatchery.
    * **Request Body Schema:** Not applicable (GET request).
    * **Example Request (conceptual):**
            `GET https://pypi.org/pypi/requests/json` (to check the 'requests' package)
    * **Success Response Schema (Code: `200 OK` - indicates name is taken):**
            A JSON object containing detailed metadata about the package, including `info`, `releases`, `urls`, etc. The specific content of the JSON is not deeply parsed by PyHatchery beyond checking the response status code.

            ```json
            {
              "info": {
                "name": "actual_package_name",
                "version": "x.y.z",
                // ... other fields
              },
              // ... other top-level keys like "releases", "urls"
            }
            ```

    * **"Name Available" Indication (Code: `404 Not Found`):**
            If the package name does not exist on PyPI, the API returns a `404 Not Found` status code. This is interpreted by PyHatchery as the name likely being available.
    * **Other Potential Responses:** PyHatchery should gracefully handle other HTTP status codes (e.g., `429 Too Many Requests`, server errors) by skipping the check and informing the user that the check could not be completed.
* **Rate Limits:** The PyPI API has rate limits, though they are generally permissive for occasional checks like this. PyHatchery should not perform an excessive number of checks. If rate-limited, the check should be skipped with a warning.
* **Link to Official Docs:** [Warehouse JSON API documentation](https://warehouse.pypa.io/api-reference/json.html)

## 2. Internal APIs Provided

Not applicable. PyHatchery is a CLI tool and does not expose any network APIs.

## 3. Cloud Service SDK Usage

Not applicable. PyHatchery does not directly interact with cloud provider SDKs for its core functionality.

## Change Log

| Change        | Date       | Version | Description                                             | Author      |
| ------------- | ---------- | ------- | ------------------------------------------------------- | ----------- |
| Initial draft | 2025-05-09 | 0.1     | Initial draft of the API Reference for PyPI consumption. | 3-Architect |
